ansible_runner.display_callback package — ansible-runner 1.0.4 documentation

# ansible_runner.display_callback package

## Submodules

## ansible_runner.display_callback.cleanup module

## ansible_runner.display_callback.display module

## ansible_runner.display_callback.events module

## ansible_runner.display_callback.minimal module

class `ansible_runner.display_callback.minimal.` `CallbackModule`(display=None, options=None)

  Bases: `ansible.plugins.callback.CallbackBase`

  This is the default callback interface, which simply prints messages to stdout when new callback events are received.

  `CALLBACK_NAME` = 'minimal'
  `CALLBACK_TYPE` = 'stdout'
  `CALLBACK_VERSION` = 2.0
  `v2_on_file_diff`(result)
  `v2_runner_on_failed`(result, ignore_errors=False)
  `v2_runner_on_ok`(result)
  `v2_runner_on_skipped`(result)
  `v2_runner_on_unreachable`(result)

## ansible_runner.display_callback.module module

class `ansible_runner.display_callback.module.` `AWXDefaultCallbackModule`

  Bases: `ansible_runner.display_callback.module.BaseCallbackModule`, `ansible.plugins.callback.default.CallbackModule`

  `CALLBACK_NAME` = 'awx_display'

class `ansible_runner.display_callback.module.` `AWXMinimalCallbackModule`

  Bases: `ansible_runner.display_callback.module.BaseCallbackModule`, `ansible_runner.display_callback.minimal.CallbackModule`

  `CALLBACK_NAME` = 'minimal'
  `v2_playbook_on_play_start`(play)
  `v2_playbook_on_task_start`(task, is_conditional)

class `ansible_runner.display_callback.module.` `BaseCallbackModule`

  Bases: `ansible.plugins.callback.CallbackBase`

  Callback module for logging ansible/ansible-playbook events.

  `CALLBACK_TYPE` = 'stdout'
  `CALLBACK_VERSION` = 2.0
  `EVENTS_WITHOUT_PLAY` = ['playbook_on_start', 'playbook_on_stats']
  `EVENTS_WITHOUT_TASK` = ['playbook_on_start', 'playbook_on_stats', 'playbook_on_setup', 'playbook_on_notify', 'playbook_on_import_for_host', 'playbook_on_not_import_for_host', 'playbook_on_no_hosts_matched', 'playbook_on_no_hosts_remaining']
  `capture_event_data`(event, **event_data)
  `clear_play`()
  `clear_task`(local=False)
  `set_play`(play)
  `set_playbook`(playbook)
  `set_task`(task, local=False)
  `v2_on_file_diff`(result)
  `v2_playbook_on_cleanup_task_start`(task)
  `v2_playbook_on_handler_task_start`(task)
  `v2_playbook_on_import_for_host`(result, imported_file)
  `v2_playbook_on_include`(included_file)
  `v2_playbook_on_no_hosts_matched`()
  `v2_playbook_on_no_hosts_remaining`()
  `v2_playbook_on_not_import_for_host`(result, missing_file)
  `v2_playbook_on_notify`(result, handler)
  `v2_playbook_on_play_start`(play)
  `v2_playbook_on_setup`()
  `v2_playbook_on_start`(playbook)
  `v2_playbook_on_stats`(stats)
  `v2_playbook_on_task_start`(task, is_conditional)
  `v2_playbook_on_vars_prompt`(varname, private=True, prompt=None, encrypt=None, confirm=False, salt_size=None, salt=None, default=None)
  `v2_runner_item_on_failed`(result)
  `v2_runner_item_on_ok`(result)
  `v2_runner_item_on_skipped`(result)
  `v2_runner_on_async_failed`(result)
  `v2_runner_on_async_ok`(result)
  `v2_runner_on_async_poll`(result)
  `v2_runner_on_failed`(result, ignore_errors=False)
  `v2_runner_on_file_diff`(result, diff)
  `v2_runner_on_no_hosts`(task)
  `v2_runner_on_ok`(result)
  `v2_runner_on_skipped`(result)
  `v2_runner_on_unreachable`(result)
  `v2_runner_retry`(result)

## Module contents

class `ansible_runner.display_callback.` `AWXDefaultCallbackModule`

  Bases: `ansible_runner.display_callback.module.BaseCallbackModule`, `ansible.plugins.callback.default.CallbackModule`

  `CALLBACK_NAME` = 'awx_display'

class `ansible_runner.display_callback.` `AWXMinimalCallbackModule`

  Bases: `ansible_runner.display_callback.module.BaseCallbackModule`, `ansible_runner.display_callback.minimal.CallbackModule`

  `CALLBACK_NAME` = 'minimal'
  `v2_playbook_on_play_start`(play)
  `v2_playbook_on_task_start`(task, is_conditional)